==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/servicelinker/kotlin/inputs/SystemAssignedIdentityAuthInfoArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.servicelinker.kotlin.inputs

import com.pulumi.azurenative.servicelinker.inputs.SystemAssignedIdentityAuthInfoArgs.builder
import com.pulumi.azurenative.servicelinker.kotlin.enums.DeleteOrUpdateBehavior
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The authentication info when authType is systemAssignedIdentity
 * @property authType The authentication type.
 * Expected value is 'systemAssignedIdentity'.
 * @property deleteOrUpdateBehavior Indicates whether to clean up previous operation when Linker is updating or deleting
 * @property roles Optional, this value specifies the Azure role to be assigned
 * @property userName Username created in the database which is mapped to a user in AAD.
 */
public data class SystemAssignedIdentityAuthInfoArgs(
    public val authType: Output<String>,
    public val deleteOrUpdateBehavior: Output<Either<String, DeleteOrUpdateBehavior>>? = null,
    public val roles: Output<List<String>>? = null,
    public val userName: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.servicelinker.inputs.SystemAssignedIdentityAuthInfoArgs> {
    override fun toJava():
        com.pulumi.azurenative.servicelinker.inputs.SystemAssignedIdentityAuthInfoArgs =
        com.pulumi.azurenative.servicelinker.inputs.SystemAssignedIdentityAuthInfoArgs.builder()
            .authType(authType.applyValue({ args0 -> args0 }))
            .deleteOrUpdateBehavior(
                deleteOrUpdateBehavior?.applyValue({ args0 ->
                    args0.transform({ args0 ->
                        args0
                    }, { args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            )
            .roles(roles?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .userName(userName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SystemAssignedIdentityAuthInfoArgs].
 */
@PulumiTagMarker
public class SystemAssignedIdentityAuthInfoArgsBuilder internal constructor() {
    private var authType: Output<String>? = null

    private var deleteOrUpdateBehavior: Output<Either<String, DeleteOrUpdateBehavior>>? = null

    private var roles: Output<List<String>>? = null

    private var userName: Output<String>? = null

    /**
     * @param value The authentication type.
     * Expected value is 'systemAssignedIdentity'.
     */
    @JvmName("wawnhlbbhccvarps")
    public suspend fun authType(`value`: Output<String>) {
        this.authType = value
    }

    /**
     * @param value Indicates whether to clean up previous operation when Linker is updating or deleting
     */
    @JvmName("jctphtsioitupanp")
    public suspend
    fun deleteOrUpdateBehavior(`value`: Output<Either<String, DeleteOrUpdateBehavior>>) {
        this.deleteOrUpdateBehavior = value
    }

    /**
     * @param value Optional, this value specifies the Azure role to be assigned
     */
    @JvmName("pewardjjcnepibvy")
    public suspend fun roles(`value`: Output<List<String>>) {
        this.roles = value
    }

    @JvmName("cxrtajxpyrqitirl")
    public suspend fun roles(vararg values: Output<String>) {
        this.roles = Output.all(values.asList())
    }

    /**
     * @param values Optional, this value specifies the Azure role to be assigned
     */
    @JvmName("wlyfivqsbgexutff")
    public suspend fun roles(values: List<Output<String>>) {
        this.roles = Output.all(values)
    }

    /**
     * @param value Username created in the database which is mapped to a user in AAD.
     */
    @JvmName("utjheiafhkwnnqum")
    public suspend fun userName(`value`: Output<String>) {
        this.userName = value
    }

    /**
     * @param value The authentication type.
     * Expected value is 'systemAssignedIdentity'.
     */
    @JvmName("hgdfvrjogwplored")
    public suspend fun authType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.authType = mapped
    }

    /**
     * @param value Indicates whether to clean up previous operation when Linker is updating or deleting
     */
    @JvmName("mpwnrgrewrhdgtqp")
    public suspend fun deleteOrUpdateBehavior(`value`: Either<String, DeleteOrUpdateBehavior>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.deleteOrUpdateBehavior = mapped
    }

    /**
     * @param value Indicates whether to clean up previous operation when Linker is updating or deleting
     */
    @JvmName("gwrtbtdqarlwfvfb")
    public fun deleteOrUpdateBehavior(`value`: String) {
        val toBeMapped = Either.ofLeft<String, DeleteOrUpdateBehavior>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.deleteOrUpdateBehavior = mapped
    }

    /**
     * @param value Indicates whether to clean up previous operation when Linker is updating or deleting
     */
    @JvmName("mtiydjihncuxolxu")
    public fun deleteOrUpdateBehavior(`value`: DeleteOrUpdateBehavior) {
        val toBeMapped = Either.ofRight<String, DeleteOrUpdateBehavior>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.deleteOrUpdateBehavior = mapped
    }

    /**
     * @param value Optional, this value specifies the Azure role to be assigned
     */
    @JvmName("xtkpehsseemgyrlt")
    public suspend fun roles(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.roles = mapped
    }

    /**
     * @param values Optional, this value specifies the Azure role to be assigned
     */
    @JvmName("xwjhsvpmunlpyygq")
    public suspend fun roles(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.roles = mapped
    }

    /**
     * @param value Username created in the database which is mapped to a user in AAD.
     */
    @JvmName("eqodudlgdexvcgfp")
    public suspend fun userName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.userName = mapped
    }

    internal fun build(): SystemAssignedIdentityAuthInfoArgs = SystemAssignedIdentityAuthInfoArgs(
        authType = authType ?: throw PulumiNullFieldException("authType"),
        deleteOrUpdateBehavior = deleteOrUpdateBehavior,
        roles = roles,
        userName = userName,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/servicelinker/kotlin/inputs/SystemAssignedIdentityAuthInfoArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.servicelinker.kotlin.inputs

import com.pulumi.azurenative.servicelinker.inputs.SystemAssignedIdentityAuthInfoArgs.builder
import com.pulumi.azurenative.servicelinker.kotlin.enums.DeleteOrUpdateBehavior
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The authentication info when authType is systemAssignedIdentity
 * @property authType The authentication type.
 * Expected value is 'systemAssignedIdentity'.
 * @property deleteOrUpdateBehavior Indicates whether to clean up previous operation when Linker is updating or deleting
 * @property roles Optional, this value specifies the Azure role to be assigned
 * @property userName Username created in the database which is mapped to a user in AAD.
 */
public data class SystemAssignedIdentityAuthInfoArgs(
    public val authType: Output<String>,
    public val deleteOrUpdateBehavior: Output<Either<String, DeleteOrUpdateBehavior>>? = null,
    public val roles: Output<List<String>>? = null,
    public val userName: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.servicelinker.inputs.SystemAssignedIdentityAuthInfoArgs> {
    override fun toJava():
        com.pulumi.azurenative.servicelinker.inputs.SystemAssignedIdentityAuthInfoArgs =
        com.pulumi.azurenative.servicelinker.inputs.SystemAssignedIdentityAuthInfoArgs.builder()
            .authType(authType.applyValue({ args0 -> args0 }))
            .deleteOrUpdateBehavior(
                deleteOrUpdateBehavior?.applyValue({ args0 ->
                    args0.transform({ args0 ->
                        args0
                    }, { args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            )
            .roles(roles?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .userName(userName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SystemAssignedIdentityAuthInfoArgs].
 */
@PulumiTagMarker
public class SystemAssignedIdentityAuthInfoArgsBuilder internal constructor() {
    private var authType: Output<String>? = null

    private var deleteOrUpdateBehavior: Output<Either<String, DeleteOrUpdateBehavior>>? = null

    private var roles: Output<List<String>>? = null

    private var userName: Output<String>? = null

    /**
     * @param value The authentication type.
     * Expected value is 'systemAssignedIdentity'.
     */
    @JvmName("pejhjjakedlgsmxn")
    public suspend fun authType(`value`: Output<String>) {
        this.authType = value
    }

    /**
     * @param value Indicates whether to clean up previous operation when Linker is updating or deleting
     */
    @JvmName("kssxvplcwftspkyg")
    public suspend
    fun deleteOrUpdateBehavior(`value`: Output<Either<String, DeleteOrUpdateBehavior>>) {
        this.deleteOrUpdateBehavior = value
    }

    /**
     * @param value Optional, this value specifies the Azure role to be assigned
     */
    @JvmName("dbfdinnqanviwxpt")
    public suspend fun roles(`value`: Output<List<String>>) {
        this.roles = value
    }

    @JvmName("nofopebmhfsoyuoj")
    public suspend fun roles(vararg values: Output<String>) {
        this.roles = Output.all(values.asList())
    }

    /**
     * @param values Optional, this value specifies the Azure role to be assigned
     */
    @JvmName("kyvnjtsaiivistth")
    public suspend fun roles(values: List<Output<String>>) {
        this.roles = Output.all(values)
    }

    /**
     * @param value Username created in the database which is mapped to a user in AAD.
     */
    @JvmName("ualnwbysigathcjx")
    public suspend fun userName(`value`: Output<String>) {
        this.userName = value
    }

    /**
     * @param value The authentication type.
     * Expected value is 'systemAssignedIdentity'.
     */
    @JvmName("samkisghvfpnxlok")
    public suspend fun authType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.authType = mapped
    }

    /**
     * @param value Indicates whether to clean up previous operation when Linker is updating or deleting
     */
    @JvmName("qeceetknqwjfspha")
    public suspend fun deleteOrUpdateBehavior(`value`: Either<String, DeleteOrUpdateBehavior>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.deleteOrUpdateBehavior = mapped
    }

    /**
     * @param value Indicates whether to clean up previous operation when Linker is updating or deleting
     */
    @JvmName("juxdaqtpltvqywsq")
    public fun deleteOrUpdateBehavior(`value`: String) {
        val toBeMapped = Either.ofLeft<String, DeleteOrUpdateBehavior>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.deleteOrUpdateBehavior = mapped
    }

    /**
     * @param value Indicates whether to clean up previous operation when Linker is updating or deleting
     */
    @JvmName("ecmocinhysyfxhyn")
    public fun deleteOrUpdateBehavior(`value`: DeleteOrUpdateBehavior) {
        val toBeMapped = Either.ofRight<String, DeleteOrUpdateBehavior>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.deleteOrUpdateBehavior = mapped
    }

    /**
     * @param value Optional, this value specifies the Azure role to be assigned
     */
    @JvmName("nhjxubwdoxfnownn")
    public suspend fun roles(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.roles = mapped
    }

    /**
     * @param values Optional, this value specifies the Azure role to be assigned
     */
    @JvmName("pkccmbucqicttxei")
    public suspend fun roles(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.roles = mapped
    }

    /**
     * @param value Username created in the database which is mapped to a user in AAD.
     */
    @JvmName("wuivptfkdrtgyqxl")
    public suspend fun userName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.userName = mapped
    }

    internal fun build(): SystemAssignedIdentityAuthInfoArgs = SystemAssignedIdentityAuthInfoArgs(
        authType = authType ?: throw PulumiNullFieldException("authType"),
        deleteOrUpdateBehavior = deleteOrUpdateBehavior,
        roles = roles,
        userName = userName,
    )
}
